/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __IOTCON_INTERNAL_LIST_H__
#define __IOTCON_INTERNAL_LIST_H__

#include <glib.h>

#include "iotcon-types.h"
#include "ic-value.h"

struct icl_list_s {
	int type;
	int ref_count;
	GList *list;
};

iotcon_list_h icl_list_ref(iotcon_list_h list);
int icl_list_create(iotcon_type_e type, iotcon_list_h *ret_list);
int icl_list_add_int(iotcon_list_h list, int val, int pos);
int icl_list_add_bool(iotcon_list_h list, bool val, int pos);
int icl_list_add_double(iotcon_list_h list, double val, int pos);
int icl_list_add_str(iotcon_list_h list, char *val, int pos);
int icl_list_add_byte_str(iotcon_list_h list, unsigned char *val, int len, int pos);
int icl_list_add_list(iotcon_list_h list, iotcon_list_h val, int pos);
int icl_list_add_attributes(iotcon_list_h list, iotcon_attributes_h val, int pos);
int icl_list_get_nth_int(iotcon_list_h list, int pos, int *val);
int icl_list_get_nth_bool(iotcon_list_h list, int pos, bool *val);
int icl_list_get_nth_double(iotcon_list_h list, int pos, double *val);
int icl_list_get_nth_str(iotcon_list_h list, int pos, char **val);
int icl_list_get_nth_byte_str(iotcon_list_h list, int pos,	unsigned char **val, int *len);
int icl_list_get_nth_list(iotcon_list_h src, int pos, iotcon_list_h *dest);
int icl_list_get_nth_attributes(iotcon_list_h list, int pos, iotcon_attributes_h *attributes);
int icl_list_remove_nth(iotcon_list_h list, int pos);
int icl_list_get_type(iotcon_list_h list, iotcon_type_e *type);
int icl_list_get_length(iotcon_list_h list, unsigned int *length);
int icl_list_foreach_int(iotcon_list_h list, iotcon_list_int_cb cb, void *user_data);
int icl_list_foreach_bool(iotcon_list_h list, iotcon_list_bool_cb cb, void *user_data);
int icl_list_foreach_double(iotcon_list_h list, iotcon_list_double_cb cb, void *user_data);
int icl_list_foreach_str(iotcon_list_h list, iotcon_list_str_cb cb, void *user_data);
int icl_list_foreach_byte_str(iotcon_list_h list, iotcon_list_byte_str_cb cb,	void *user_data);
int icl_list_foreach_list(iotcon_list_h list, iotcon_list_list_cb cb, void *user_data);
int icl_list_foreach_attributes(iotcon_list_h list, iotcon_list_attributes_cb cb, void *user_data);
int icl_list_destroy(iotcon_list_h list);


#endif /* __IOTCON_INTERNAL_LIST_H__ */
