/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __IOTCON_INTERNAL_QUERY_H__
#define __IOTCON_INTERNAL_QUERY_H__

#include <glib.h>
#include "iotcon-types.h"

/**
 * @brief The maximum length which can be held in a query.
 *
 * @since_tizen 3.0
 */
#define ICL_QUERY_LENGTH_MAX 64

#define ICL_QUERY_KEY_RESOURCE_TYPE "rt"
#define ICL_QUERY_KEY_INTERFACE "if"

struct icl_query {
	int len;
	GHashTable *hash;
};

int icl_query_create(iotcon_query_h *ret_query);
int icl_query_destroy(iotcon_query_h query);
int icl_query_get_resource_type(iotcon_query_h query, char **resource_type);
int icl_query_get_interface(iotcon_query_h query, char **resource_iface);
int icl_query_set_resource_type(iotcon_query_h query, const char *resource_type);
int icl_query_set_interface(iotcon_query_h query, const char *resource_iface);
int icl_query_add(iotcon_query_h query, const char *key, const char *value);
int icl_query_remove(iotcon_query_h query, const char *key);
int icl_query_lookup(iotcon_query_h query, const char *key, char **data);
int icl_query_foreach(iotcon_query_h query, iotcon_query_foreach_cb cb, void *user_data);

#endif /* __IOTCON_INTERNAL_QUERY_H__ */
