/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __IOTCON_INTERNAL_REPRESENTATION_H__
#define __IOTCON_INTERNAL_REPRESENTATION_H__

#include <glib.h>

#include "iotcon-types.h"
#include "ic-value.h"

struct icl_attributes_s {
	int ref_count;
	GHashTable *hash_table;
};

struct icl_representation_s {
	char *uri_path;
	int ref_count;
	int visibility;
	GList *children;
	iotcon_resource_types_h res_types;
	iotcon_resource_interfaces_h interfaces;
	struct icl_attributes_s *attributes;
};

iotcon_representation_h icl_representation_ref(iotcon_representation_h repr);
int icl_representation_create(iotcon_representation_h *ret_repr);
int icl_representation_destroy(iotcon_representation_h repr);
int icl_representation_get_uri_path(iotcon_representation_h repr,
		char **uri_path);
int icl_representation_set_uri_path(iotcon_representation_h repr,
		const char *uri_path);
int icl_representation_get_resource_types(iotcon_representation_h repr,
		iotcon_resource_types_h *types);
int icl_representation_set_resource_types(iotcon_representation_h repr,
		iotcon_resource_types_h types);
int icl_representation_get_resource_interfaces(
		iotcon_representation_h repr, iotcon_resource_interfaces_h *ifaces);
int icl_representation_set_resource_interfaces(
		iotcon_representation_h repr, iotcon_resource_interfaces_h ifaces);
int icl_representation_set_attributes(iotcon_representation_h repr,
		iotcon_attributes_h attributes);
int icl_representation_get_attributes(iotcon_representation_h repr,
		iotcon_attributes_h *attributes);
int icl_representation_add_child(iotcon_representation_h parent,
		iotcon_representation_h child);
int icl_representation_remove_child(iotcon_representation_h parent,
		iotcon_representation_h child);
int icl_representation_foreach_children(iotcon_representation_h parent,
		iotcon_children_cb cb, void *user_data);
int icl_representation_get_child_count(iotcon_representation_h parent,
		unsigned int *count);
int icl_representation_get_nth_child(iotcon_representation_h parent,
		int pos, iotcon_representation_h *child);
int icl_representation_clone(const iotcon_representation_h src,
		iotcon_representation_h *dest);
int icl_representation_compare(iotcon_representation_h repr1,
		iotcon_representation_h repr2);

#endif /* __IOTCON_INTERNAL_REPRESENTATION_H__ */
