/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <tizen_type.h>

#include "iotcon.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-representation.h"
#include "ic-request.h"
#include "ic-resource-types.h"
#include "ic-resource-interfaces.h"
#include "ic-resource.h"
#include "ic-ioty.h"

bool icl_resource_check_uri_path(const char *uri_path)
{
	int i;

	RETV_IF(NULL == uri_path, false);

	if (ICL_URI_PATH_LENGTH_MAX < strlen(uri_path)) {
		ERR("The length of URI path(%s) should be less than or equal to %d.", uri_path,
				ICL_URI_PATH_LENGTH_MAX);
		return false;
	}

	if ('/' != uri_path[0]) {
		ERR("URI path should start with '/'");
		return false;
	}

	for (i = 0; '\0' != uri_path[i]; i++) {
		if ('?' == uri_path[i]) {
			ERR("'?' is not allowed");
			return false;
		}
	}

	return true;
}


static bool _check_type_interface(const char *src)
{
	int i;

	if (src[0] < 'a' || 'z' < src[0]) {
		ERR("'%c' is not allowed", src[0]);
		return false;
	}

	for (i = 1; '\0' != src[i]; i++) {
		if ('.' == src[i])
			continue;
		if ('-' == src[i])
			continue;
		if ((src[i] < 'a' || 'z' < src[i]) && (src[i] < '0' || '9' < src[i])) {
			ERR("'%c' is not allowed", src[i]);
			return false;
		}
	}
	return true;
}


bool icl_resource_check_type(const char *type)
{
	RETV_IF(NULL == type, false);

	if (ICL_RESOURCE_TYPE_LENGTH_MAX < strlen(type)) {
		ERR("The length of type(%s) should be less than or equal to %d.", type,
				ICL_RESOURCE_TYPE_LENGTH_MAX);
		return false;
	}

	return _check_type_interface(type);
}


bool icl_resource_check_interface(const char *iface)
{
	RETV_IF(NULL == iface, false);

	return _check_type_interface(iface);
}

