/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdlib.h>
#include <errno.h>

#include "iotcon-types.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-attributes.h"
#include "ic-representation.h"
#include "ic-value.h"
#include "ic-list.h"

API int iotcon_list_create(iotcon_type_e type, iotcon_list_h *ret_list)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_create(type, ret_list);
}


API int iotcon_list_add_int(iotcon_list_h list, int val, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_int(list, val, pos);
}


API int iotcon_list_add_bool(iotcon_list_h list, bool val, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_bool(list, val, pos);
}


API int iotcon_list_add_double(iotcon_list_h list, double val, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_double(list, val, pos);
}


API int iotcon_list_add_str(iotcon_list_h list, char *val, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_str(list, val, pos);
}


API int iotcon_list_add_byte_str(iotcon_list_h list, unsigned char *val, int len, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_byte_str(list, val, len, pos);
}


API int iotcon_list_add_list(iotcon_list_h list, iotcon_list_h val, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_list(list, val, pos);
}


API int iotcon_list_add_attributes(iotcon_list_h list, iotcon_attributes_h val, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_add_attributes(list, val, pos);
}


API int iotcon_list_get_nth_int(iotcon_list_h list, int pos, int *val)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_int(list, pos, val);
}


API int iotcon_list_get_nth_bool(iotcon_list_h list, int pos, bool *val)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_bool(list, pos, val);
}


API int iotcon_list_get_nth_double(iotcon_list_h list, int pos, double *val)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_double(list, pos, val);
}


API int iotcon_list_get_nth_str(iotcon_list_h list, int pos, char **val)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_str(list, pos, val);
}


API int iotcon_list_get_nth_byte_str(iotcon_list_h list, int pos, unsigned char **val, int *len)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_byte_str(list, pos, val, len);
}


API int iotcon_list_get_nth_list(iotcon_list_h src, int pos, iotcon_list_h *dest)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_list(src, pos, dest);
}


API int iotcon_list_get_nth_attributes(iotcon_list_h list, int pos, iotcon_attributes_h *attributes)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_nth_attributes(list, pos, attributes);
}


API int iotcon_list_remove_nth(iotcon_list_h list, int pos)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_remove_nth(list, pos);
}


API int iotcon_list_get_type(iotcon_list_h list, iotcon_type_e *type)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_type(list, type);
}


API int iotcon_list_get_length(iotcon_list_h list, unsigned int *length)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_get_length(list, length);
}


API int iotcon_list_foreach_int(iotcon_list_h list, iotcon_list_int_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_int(list, cb, user_data);
}

API int iotcon_list_foreach_bool(iotcon_list_h list, iotcon_list_bool_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_bool(list, cb, user_data);
}

API int iotcon_list_foreach_double(iotcon_list_h list, iotcon_list_double_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_double(list, cb, user_data);
}

API int iotcon_list_foreach_str(iotcon_list_h list, iotcon_list_str_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_str(list, cb, user_data);
}

API int iotcon_list_foreach_byte_str(iotcon_list_h list, iotcon_list_byte_str_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_byte_str(list, cb, user_data);
}

API int iotcon_list_foreach_list(iotcon_list_h list, iotcon_list_list_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_list(list, cb, user_data);
}

API int iotcon_list_foreach_attributes(iotcon_list_h list, iotcon_list_attributes_cb cb, void *user_data)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_foreach_attributes(list, cb, user_data);
}


API int iotcon_list_destroy(iotcon_list_h list)
{
	API_CALL;

	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_list_destroy(list);
}
