/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <stdlib.h>
#include <errno.h>
#include <glib.h>

#include "iotcon-types.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-options.h"

API int iotcon_options_create(iotcon_options_h *ret_options)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_options_create(ret_options);
}


API int iotcon_options_destroy(iotcon_options_h options)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_options_destroy(options);
}


/* iotcon_options_h can have up to 2 options.
 * option id is always situated between 2048 and 3000.
 * Length of option data is less than or equal to 15. */
API int iotcon_options_add(iotcon_options_h options, unsigned short id,
		const char *data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_options_add(options, id, data);
}


API int iotcon_options_remove(iotcon_options_h options, unsigned short id)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_options_remove(options, id);
}


API int iotcon_options_lookup(iotcon_options_h options, unsigned short id,
		char **data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_options_lookup(options, id, data);
}


API int iotcon_options_foreach(iotcon_options_h options,
		iotcon_options_foreach_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_options_foreach(options, cb, user_data);
}
