/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <stdlib.h>
#include <stdint.h>
#include <unistd.h>
#include <errno.h>
#include <glib.h>
#include <octypes.h>
#include <ocstack.h>
#include <ocprovisioningmanager.h>
#include <oxmjustworks.h>
#include <oxmrandompin.h>
#include <pmutility.h>

#include "iotcon.h"
#include "iotcon-provisioning.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-ioty.h"
#include "ic-provisioning-struct.h"

/* LCOV_EXCL_START */
API int iotcon_provisioning_device_clone(iotcon_provisioning_device_h device,
		iotcon_provisioning_device_h *cloned_device)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_clone(device, cloned_device);
}

API int iotcon_provisioning_device_destroy(iotcon_provisioning_device_h device)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_destroy(device);
}

API int iotcon_provisioning_device_get_host_address(iotcon_provisioning_device_h device,
		char **host_address)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_get_host_address(device, host_address);
}

API int iotcon_provisioning_device_get_connectivity_type(
		iotcon_provisioning_device_h device,
		iotcon_connectivity_type_e *connectivity_type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_get_connectivity_type(device, connectivity_type);
}

API int iotcon_provisioning_device_get_id(iotcon_provisioning_device_h device,
		char **device_id)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_get_id(device, device_id);
}

API int iotcon_provisioning_device_get_oxm(iotcon_provisioning_device_h device,
		iotcon_provisioning_oxm_e *oxm)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_get_oxm(device, oxm);
}

API int iotcon_provisioning_device_is_owned(iotcon_provisioning_device_h device,
		bool *is_owned)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_device_is_owned(device, is_owned);
}

API int iotcon_provisioning_acl_create(iotcon_provisioning_acl_h *acl)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_acl_create(acl);
}

API int iotcon_provisioning_acl_destroy(iotcon_provisioning_acl_h acl)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_acl_destroy(acl);
}

API int iotcon_provisioning_acl_set_subject(iotcon_provisioning_acl_h acl,
		iotcon_provisioning_device_h device)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_acl_set_subject(acl, device);
}

API int iotcon_provisioning_acl_set_all_subject(iotcon_provisioning_acl_h acl)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_acl_set_all_subject(acl);
}

API int iotcon_provisioning_acl_add_resource(iotcon_provisioning_acl_h acl,
		const char *uri_path)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_acl_add_resource(acl, uri_path);
}

API int iotcon_provisioning_acl_set_permission(iotcon_provisioning_acl_h acl,
		int permission)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_acl_set_permission(acl, permission);
}
/* LCOV_EXCL_STOP */
