/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <stdlib.h>
#include <stdint.h>
#include <unistd.h>
#include <errno.h>
#include <glib.h>

#include "iotcon.h"
#include "iotcon-provisioning.h"
#include "ic-provisioning-struct.h"
#include "ic-provisioning.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-ioty.h"
#include "ic-ioty-parse.h"

/* LCOV_EXCL_START */
API int iotcon_provisioning_initialize(const char *file_path, const char *db_path)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(false == ic_utils_check_permission((IC_PERMISSION_INTERNET
					|IC_PERMISSION_NETWORK_GET)), IOTCON_ERROR_PERMISSION_DENIED);
	return icl_provisioning_initialize(file_path, db_path);
}

API int iotcon_provisioning_set_randompin_cb(iotcon_provisioning_randompin_cb cb,
		void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_set_randompin_cb(cb, user_data);
}

API int iotcon_provisioning_register_unowned_device(
		iotcon_provisioning_device_h device,
		iotcon_provisioning_ownership_transfer_cb cb,
		void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_register_unowned_device(device, cb, user_data);
}

API int iotcon_provisioning_provision_cred(iotcon_provisioning_device_h device1,
		iotcon_provisioning_device_h device2,
		iotcon_provisioning_provision_cred_cb cb,
		void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_provision_cred(device1, device2, cb, user_data);
}

API int iotcon_provisioning_provision_acl(iotcon_provisioning_device_h device,
		iotcon_provisioning_acl_h acl,
		iotcon_provisioning_provision_acl_cb cb,
		void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_provision_acl(device, acl, cb, user_data);
}

API int iotcon_provisioning_pairwise_devices(iotcon_provisioning_device_h device1,
		iotcon_provisioning_acl_h acl1,
		iotcon_provisioning_device_h device2,
		iotcon_provisioning_acl_h acl2,
		iotcon_provisioning_pairwise_devices_cb cb,
		void *user_data)

{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_pairwise_devices(device1, acl1, device2, acl2, cb, user_data);
}

API int iotcon_provisioning_unlink_pairwise(iotcon_provisioning_device_h device1,
		iotcon_provisioning_device_h device2,
		iotcon_provisioning_unlink_pairwise_cb cb,
		void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_unlink_pairwise(device1, device2, cb, user_data);
}

API int iotcon_provisioning_find_device(iotcon_provisioning_find_e type,
		iotcon_provisioning_found_device_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_find_device(type, cb, user_data);
}

API int iotcon_provisioning_remove_device(const char *device_id,
		iotcon_provisioning_remove_device_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_provisioning_remove_device(device_id, cb, user_data);
}
/* LCOV_EXCL_STOP */
