/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <glib.h>

#include "iotcon-types.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-resource.h"
#include "ic-resource-types.h"
#include "ic-query.h"

API int iotcon_query_create(iotcon_query_h *ret_query)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_create(ret_query);
}

API int iotcon_query_destroy(iotcon_query_h query)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_destroy(query);
}

API int iotcon_query_get_resource_type(iotcon_query_h query,
		char **resource_type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_get_resource_type(query, resource_type);
}

API int iotcon_query_get_interface(iotcon_query_h query, char **resource_iface)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_get_interface(query, resource_iface);
}

API int iotcon_query_set_resource_type(iotcon_query_h query, const char *resource_type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_set_resource_type(query, resource_type);
}

API int iotcon_query_set_interface(iotcon_query_h query, const char *resource_iface)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_set_interface(query, resource_iface);
}

/* The full length of query should be less than or equal to 64. */
API int iotcon_query_add(iotcon_query_h query, const char *key, const char *value)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_add(query, key, value);
}

API int iotcon_query_remove(iotcon_query_h query, const char *key)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_remove(query, key);
}

API int iotcon_query_lookup(iotcon_query_h query, const char *key, char **data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_lookup(query, key, data);
}

API int iotcon_query_foreach(iotcon_query_h query, iotcon_query_foreach_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_query_foreach(query, cb, user_data);
}

