/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <limits.h>
#include <glib.h>

#include "iotcon-types.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-resource.h"
#include "ic-resource-types.h"
#include "ic-resource-interfaces.h"
#include "ic-response.h"
#include "ic-list.h"
#include "ic-value.h"
#include "ic-attributes.h"
#include "ic-representation.h"

API int iotcon_representation_create(iotcon_representation_h *ret_repr)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_create(ret_repr);
}

API int iotcon_representation_destroy(iotcon_representation_h repr)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_destroy(repr);
}

API int iotcon_representation_get_uri_path(iotcon_representation_h repr,
		char **uri_path)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_get_uri_path(repr, uri_path);
}

API int iotcon_representation_set_uri_path(iotcon_representation_h repr,
		const char *uri_path)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_set_uri_path(repr, uri_path);
}

API int iotcon_representation_get_resource_types(iotcon_representation_h repr,
		iotcon_resource_types_h *types)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_get_resource_types(repr, types);
}

API int iotcon_representation_set_resource_types(iotcon_representation_h repr,
		iotcon_resource_types_h types)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_set_resource_types(repr, types);
}

API int iotcon_representation_get_resource_interfaces(
		iotcon_representation_h repr, iotcon_resource_interfaces_h *ifaces)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_get_resource_interfaces(repr, ifaces);
}

API int iotcon_representation_set_resource_interfaces(
		iotcon_representation_h repr, iotcon_resource_interfaces_h ifaces)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_set_resource_interfaces(repr, ifaces);
}

API int iotcon_representation_set_attributes(iotcon_representation_h repr,
		iotcon_attributes_h attributes)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_set_attributes(repr, attributes);
}

API int iotcon_representation_get_attributes(iotcon_representation_h repr,
		iotcon_attributes_h *attributes)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_get_attributes(repr, attributes);
}

API int iotcon_representation_add_child(iotcon_representation_h parent,
		iotcon_representation_h child)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_add_child(parent, child);
}


API int iotcon_representation_remove_child(iotcon_representation_h parent,
		iotcon_representation_h child)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_add_child(parent, child);
}


API int iotcon_representation_foreach_children(iotcon_representation_h parent,
		iotcon_children_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_foreach_children(parent, cb, user_data);
}

API int iotcon_representation_get_child_count(iotcon_representation_h parent,
		unsigned int *count)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_get_child_count(parent, count);
}

API int iotcon_representation_get_nth_child(iotcon_representation_h parent,
		int pos, iotcon_representation_h *child)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_get_nth_child(parent, pos, child);
}

API int iotcon_representation_clone(const iotcon_representation_h src,
		iotcon_representation_h *dest)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_representation_clone(src, dest);
}
