/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "iotcon-types.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-request.h"

API int iotcon_request_get_host_address(iotcon_request_h request,
		char **host_address)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == host_address, IOTCON_ERROR_INVALID_PARAMETER);

	*host_address = request->host_address;

	return IOTCON_ERROR_NONE;
}


API int iotcon_request_get_connectivity_type(iotcon_request_h request,
		iotcon_connectivity_type_e *connectivity_type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == connectivity_type, IOTCON_ERROR_INVALID_PARAMETER);

	*connectivity_type = request->connectivity_type;

	return IOTCON_ERROR_NONE;
}


/* The content of the request should not be freed by user. */
API int iotcon_request_get_representation(iotcon_request_h request,
		iotcon_representation_h *repr)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == repr, IOTCON_ERROR_INVALID_PARAMETER);

	*repr = request->repr;

	return IOTCON_ERROR_NONE;
}


API int iotcon_request_get_request_type(iotcon_request_h request,
		iotcon_request_type_e *type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == type, IOTCON_ERROR_INVALID_PARAMETER);

	*type = request->type;

	return IOTCON_ERROR_NONE;
}


/* The content of the request should not be freed by user. */
API int iotcon_request_get_options(iotcon_request_h request,
		iotcon_options_h *options)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == options, IOTCON_ERROR_INVALID_PARAMETER);
	WARN_IF(NULL == request->header_options, "Not Set header options");

	*options = request->header_options;

	return IOTCON_ERROR_NONE;
}


/* The content of the request should not be freed by user. */
API int iotcon_request_get_query(iotcon_request_h request, iotcon_query_h *query)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == query, IOTCON_ERROR_INVALID_PARAMETER);
	WARN_IF(NULL == request->query, "Not Set query");

	*query = request->query;

	return IOTCON_ERROR_NONE;
}


API int iotcon_request_get_observe_type(iotcon_request_h request,
		iotcon_observe_type_e *observe_type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == observe_type, IOTCON_ERROR_INVALID_PARAMETER);

	*observe_type = request->observation_info.action;

	return IOTCON_ERROR_NONE;
}


API int iotcon_request_get_observe_id(iotcon_request_h request, int *observe_id)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(NULL == request, IOTCON_ERROR_INVALID_PARAMETER);
	RETV_IF(NULL == observe_id, IOTCON_ERROR_INVALID_PARAMETER);

	*observe_id = request->observation_info.observe_id;

	return IOTCON_ERROR_NONE;
}

