/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <glib.h>

#include "iotcon-types.h"
#include "ic.h"
#include "ic-utils.h"
#include "ic-resource.h"
#include "ic-resource-types.h"

API int iotcon_resource_types_create(iotcon_resource_types_h *ret_types)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_resource_types_create(ret_types);
}


API int iotcon_resource_types_destroy(iotcon_resource_types_h types)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_resource_types_destroy(types);
}


/* The length of resource type should be less than or equal to 61.
 * Duplicate strings are not allowed. */
API int iotcon_resource_types_add(iotcon_resource_types_h types, const char *type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_resource_types_add(types, type);
}


API int iotcon_resource_types_remove(iotcon_resource_types_h types,
		const char *type)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_resource_types_remove(types, type);
}


API int iotcon_resource_types_foreach(iotcon_resource_types_h types,
		iotcon_resource_types_foreach_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_resource_types_foreach(types, cb, user_data);
}


API int iotcon_resource_types_clone(iotcon_resource_types_h src,
		iotcon_resource_types_h *dest)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	return icl_resource_types_clone(src, dest);
}

