/*
 * Copyright (c) 2015 - 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <glib.h>
#include <glib-object.h>

#include "ic.h"
#include "ic-utils.h"
#include "ic-ioty.h"

API int iotcon_initialize(const char *file_path)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);
	RETV_IF(false == ic_utils_check_permission((IC_PERMISSION_INTERNET|IC_PERMISSION_NETWORK_GET)),
			IOTCON_ERROR_PERMISSION_DENIED);

	return icl_initialize(file_path, false);
}

API int iotcon_deinitialize(void)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_deinitialize();
}

API int iotcon_get_timeout(int *timeout_seconds)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_get_timeout(timeout_seconds);
}

API int iotcon_set_timeout(int timeout_seconds)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_set_timeout(timeout_seconds);
}

API int iotcon_polling_get_interval(int *interval)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_polling_get_interval(interval);
}

API int iotcon_polling_set_interval(int interval)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_polling_set_interval(interval);
}

API int iotcon_polling_invoke(void)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_polling_invoke();
}

API int iotcon_add_generated_pin_cb(iotcon_generated_pin_cb cb, void *user_data)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_ioty_add_generated_pin_cb(cb, user_data);
}

API int iotcon_remove_generated_pin_cb(iotcon_generated_pin_cb cb)
{
	API_CALL;
	RETV_IF(false == ic_utils_check_ocf_feature(), IOTCON_ERROR_NOT_SUPPORTED);

	return icl_ioty_remove_generated_pin_cb(cb);
}
